# Inputs
## Under data/
### Create a directory named with songTitle (eg. lyrics), under this directory:
#### songTitle.txt (from www.genius.com )
#### songTitlewithTime.txt (from we sing)

# Outputs
## Under result/
### songTitle_timestamp.txt

# Run:
## python lyrics_match.py songTitle